@@ -1,5 +1,10 @@
 #!/usr/bin/env perl
 
+# Note to run this you will probably want to build with ./configure
+# --disable-shared. You don't want to valgrind the libtool script.
+#
+# Also make sure you compile the tests first (`make check').
+
 use strict;
 use warnings;
 
@@ -11,11 +16,13 @@ my $top_dir = "$Bin/..";
 
 my $output;
 
-my @tests = glob "$top_dir/t/.libs/lt-*_t";
+my @tests;
+push @tests, glob "$top_dir/t/*_t";
+push @tests, glob "$top_dir/t/*-t";
 
 my @mmdblookup = (
     "$top_dir/bin/mmdblookup",
-    '--file', "$top_dir/maxmind-db/test-data/MaxMind-DB-test-decoder.mmdb",
+    '--file', "$top_dir/t/maxmind-db/test-data/MaxMind-DB-test-decoder.mmdb",
     '--ip',
 );
 
@@ -31,7 +38,7 @@ my @cmds = (
 for my $cmd (@cmds) {
     my $output;
     run3(
-        [ qw( valgrind --leak-check=full -- ), @{$cmd} ],
+        [ qw( valgrind -v --leak-check=full --show-leak-kinds=all -- ), @{$cmd} ],
         \undef,
         \$output,
         \$output,
